<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AuthDialog</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Forme</translation>
    </message>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">Plus d&apos;appareils</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">Biométrique</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Mot de passe</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Réessayez</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">Ouvrir</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">Connecté</translation>
    </message>
    <message>
        <source>Password Incorrect, Please try again</source>
        <translation>Mot de passe incorrect, veuillez réessayer</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Forme</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation type="obsolete">Plus</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="obsolete">Réessayez</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Mot de passe</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">Empreinte digitale</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">Visage</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">VoicePrint</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Forme</translation>
    </message>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">Veuillez sélectionner d&apos;autres appareils biométriques</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">Type d&apos;appareil:</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">Nom de l&apos;appareil:</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished">Empreinte digitale</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished">FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished">Iris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished">Visage</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished">VoicePrint</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation>KeyboardWidget</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>Form</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Rendez-vous amoureux</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation type="vanished">Changer d&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>SwitchUser</source>
        <translation type="obsolete">Changer d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The screensaver is active.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The screensaver is inactive.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <source>Set as desktop wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic switching</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <source>You have rested:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation>Commande de démarrage pour l&apos;ukui ScreenSaver.</translation>
    </message>
    <message>
        <source>lock the screen immediately</source>
        <translation>verrouiller l&apos;écran immédiatement</translation>
    </message>
    <message>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation>Boîte de dialogue pour l&apos;écran de veille ukui.</translation>
    </message>
    <message>
        <source>activated by session idle signal</source>
        <translation>activé par le signal d&apos;inactivité de la session</translation>
    </message>
    <message>
        <source>Screensaver for ukui-screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>show on root window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>show on window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>window id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>query the status of the screen saver</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
